@@ -14,17 +14,17 @@ class TagsPrismaCloudAPIComputeMixin:
         return result
 
     def tag_delete(self, tag_id):
-        result = self.execute_compute('DELETE', 'api/v1/tags/%s', % tag_id)
+        result = self.execute_compute('DELETE', 'api/v1/tags/%s' % tag_id)
         return result
 
     def tag_update(self, tag_id, body_params):
-        result = self.execute_compute('PUT', 'api/v1/tags/%s', % tag_id, body_params=body_params)
+        result = self.execute_compute('PUT', 'api/v1/tags/%s' % tag_id, body_params=body_params)
         return result
 
     def tag_delete_vulnerability(self, tag_id, body_params):
-        result = self.execute_compute('PUT', 'api/v1/tags/%s/vuln', % tag_id, body_params=body_params)
+        result = self.execute_compute('PUT', 'api/v1/tags/%s/vuln' % tag_id, body_params=body_params)
         return result
 
     def tag_set_vulnerability(self, tag_id, body_params):
-        result = self.execute_compute('POST', 'api/v1/tags/%s/vuln', % tag_id, body_params=body_params)
+        result = self.execute_compute('POST', 'api/v1/tags/%s/vuln' % tag_id, body_params=body_params)
         return result
